@@ -155,9 +155,7 @@ def get_table_value(array: numpy.recarray, col_match, col_match_with, col_val):
         value = _get_single_table_value(array, col_match, col_match_with, col_val) if single else \
             reduce(reducer, enumerate(col_match), array)[col_val][0]
         return None if _is_missing_value(value) else value
-    except IndexError:
-        return None
-    except ValueError:
+    except Exception:
         return None
 
 
